@@ -5,8 +5,8 @@ import mcpi
 
 from mcpi.vec3 import Vec3
 
-from .scene import Scene
 from .thing import Thing
+from .world import World
 
 
 class BlocksGallery(Thing):
@@ -21,7 +21,7 @@ class BlocksGallery(Thing):
         """
 
         for i in range(1, self.MAX_BLOCK_NUMBER):
-            Scene.server.setBlock(self.position.x + i, self.position.y,
+            World.server.setBlock(self.position.x + i, self.position.y,
                                   self.position.z, mcpi.block.Block(i))
 
         self._end_position = Vec3(self.position.x + self.MAX_BLOCK_NUMBER - 1,
