@@ -1,7 +1,7 @@
 # Licensed under the terms of http://www.apache.org/licenses/LICENSE-2.0
 # Author (©): Alvaro del Castillo
 
-from mcthings.scene import Scene
+from mcthings.world import World
 from mcthings.thing import Thing
 
 
@@ -11,7 +11,7 @@ class Circle(Thing):
     """ radius of the Sphere """
 
     def build(self):
-        Scene.drawing.drawCircle(
+        World.drawing.drawCircle(
             self.position.x,
             self.position.y,
             self.position.z,
