@@ -25,6 +25,11 @@ class World:
         """ Add a new scene to the world """
         cls.scenes.append(scene)
 
+    @classmethod
+    def first_scene(cls):
+        """ Return the first scene used be default """
+        return cls.scenes[0]
+
     @classmethod
     def build(cls):
         """ Build all the scenes inside the world """
